aboutsummaryrefslogtreecommitdiff
path: root/lib/Bytecode/Reader/Reader.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Bytecode/Reader/Reader.h')
-rw-r--r--lib/Bytecode/Reader/Reader.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/Bytecode/Reader/Reader.h b/lib/Bytecode/Reader/Reader.h
index 25410838d3..21eb8462fb 100644
--- a/lib/Bytecode/Reader/Reader.h
+++ b/lib/Bytecode/Reader/Reader.h
@@ -229,8 +229,8 @@ protected:
void ParseConstantPool(ValueTable& Values, TypeListTy& Types,
bool isFunction);
- /// @brief Parse a single constant value
- Constant* ParseConstantValue(unsigned TypeID);
+ /// @brief Parse a single constant pool value
+ Value *ParseConstantPoolValue(unsigned TypeID);
/// @brief Parse a block of types constants
void ParseTypes(TypeListTy &Tab, unsigned NumEntries);